@@ -3,7 +3,6 @@ from PIL import Image
 
 import urllib.request
 
-
 CHARS_BY_DENSITY = '" .`-_\':,;^=+/"|)\\<>)iv%xclrs{*}I?!][1taeo7zjLunT#JCwfy325Fp6mqSghVd4EgXPGZbYkOA&8U$@KHDBWNMR0Q'
 
 COLOR_DATA = [
@@ -22,8 +21,8 @@ PALETTE = [ [[(v/255.0)**2.2 for v in x[0]], x[1]] for x in COLOR_DATA ]
 
 def from_url(url: str, **kwargs) -> None:
 	with urllib.request.urlopen(url) as response:
-		img = Image.open(response)
-		return from_image(img, **kwargs)
+		with Image.open(response) as img:
+			return from_image(img, **kwargs)
 
 
 def from_image_file(img_path: str, **kwargs) -> None:
